# Chain3.py


A Python implementation of [Chain3.js](https://github.com/MOACChain/moac-core/wiki/Chain3)

* Python 3.5+ support


## Quickstart

```python
from chain3 import Chain3

w3 = Chain3()

print('chain3 block number:', w3.mc.blockNumber)

